﻿Imports System.Net
Imports System.Windows
Imports System.Windows.Controls
Imports System.Windows.Documents
Imports System.Windows.Input
Imports System.Windows.Media
Imports System.Windows.Media.Animation
Imports System.Windows.Shapes
Imports SudukoArticle.ViewModels
Imports SudukoArticle.Utility
Imports Microsoft.Devices

Namespace SudukoArticle.Views
	Partial Public Class SquareView
		Inherits UserControl
		Private _viewModel As SquareViewModel
		Public Sub New(ByVal viewModel As SquareViewModel)
			InitializeComponent()
			_viewModel = viewModel
			Me.DataContext = _viewModel
			AddHandler _viewModel.PropertyChanged, AddressOf viewModel_PropertyChanged
			SetColors()
			SetThickness()
		End Sub

        Private Sub viewModel_PropertyChanged(ByVal sender As Object,
                                              ByVal e As System.ComponentModel.PropertyChangedEventArgs)
            If String.Equals(e.PropertyName, "CurrentBoxState") Then
                SetColors()
            End If
        End Sub

		Private Sub SetColors()
			Select Case _viewModel.CurrentBoxState
				Case BoxStates.UnEditable
					MainText.Foreground = CType(Resources("PhoneDisabledBrush"), SolidColorBrush)
					LayoutRoot.Background = CType(Resources("PhoneBackgroundBrush"), SolidColorBrush)
				Case BoxStates.Invalid
					MainText.Foreground = CType(Resources("PhoneContrastForegroundBrush"), SolidColorBrush)
					LayoutRoot.Background = CType(Resources("PhoneContrastBackgroundBrush"), SolidColorBrush)
					VibrateController.Default.Start(TimeSpan.FromMilliseconds(200))
				Case BoxStates.Selected
					MainText.Foreground = CType(Resources("PhoneAccentBrush"), SolidColorBrush)
					LayoutRoot.Background = CType(Resources("PhoneChromeBrush"), SolidColorBrush)
				Case Else
					MainText.Foreground = CType(Resources("PhoneAccentBrush"), SolidColorBrush)
					LayoutRoot.Background = CType(Resources("PhoneBackgroundBrush"), SolidColorBrush)
			End Select
		End Sub

		Private Sub SetThickness()
            Dim topBorder = 1
            Dim rightBorder = 1
            Dim leftBorder = 1
            Dim bottomBorder = 1
			If _viewModel.Row Mod 3 = 0 Then
				topBorder = 3
			End If
			If _viewModel.Column Mod 3 = 0 Then
				leftBorder = 3
			End If
			If _viewModel.Row = 8 Then
				bottomBorder = 3
			End If
			If _viewModel.Column = 8 Then
				rightBorder = 3
			End If

			BoxGridBorder.BorderThickness = New Thickness(leftBorder, topBorder, rightBorder, bottomBorder)
		End Sub

		Public Event BoxClicked As EventHandler

		Private Sub LayoutRoot_MouseLeftButtonDown(ByVal sender As Object, ByVal e As MouseButtonEventArgs)
			RaiseEvent BoxClicked(Me, Nothing)
		End Sub
	End Class
End Namespace
